roast_opts

Function roast_opts 

pub fn roast_opts(
    roast_args: &RoastArgs,
    start_trace: bool,
) -> Result<(), Error>
Processes CLI arguments that matches the fields in the RoastArgs constructor. There is an optional activation of tracing subscriber for logs as the second parameter which is useful for cases where you need to log the important values that are passed down in this function. NOTE: Always pass false to the start_trace parameter if there is already a global tracing activated in the environment.