pub fn start_tracing()Expand description
Utility function to start tracing subscriber in the environment for logging.
Supports coloured and no coloured outputs using terminfo::capability.
pub fn start_tracing()Utility function to start tracing subscriber in the environment for logging.
Supports coloured and no coloured outputs using terminfo::capability.